# MaskFlownet

## Original code

[https://github.com/cattaneod/MaskFlownet-Pytorch](https://github.com/cattaneod/MaskFlownet-Pytorch)

## Official implementation (MXNet)

[https://github.com/microsoft/MaskFlownet](https://github.com/microsoft/MaskFlownet)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{zhao2020maskflownet,
  author = {Zhao, Shengyu and Sheng, Yilun and Dong, Yue and Chang, Eric I-Chao and Xu, Yan},
  title = {MaskFlownet: Asymmetric Feature Matching with Learnable Occlusion Mask},
  booktitle = {Proceedings of the IEEE Conference on Computer Vision and Pattern Recognition (CVPR)},
  year = {2020}
}
```